@@ -2,7 +2,7 @@ use assert_fs::prelude::{FileTouch, PathChild};
 use assert_fs::{fixture::FileWriteStr, prelude::PathCreateDir};
 use indoc::indoc;
 
-use uv_python::platform::{Arch, Os};
+use uv_platform::{Arch, Os};
 use uv_static::EnvVars;
 
 use crate::common::{TestContext, uv_snapshot, venv_bin_path};
@@ -728,6 +728,77 @@ fn python_find_venv_invalid() {
     "###);
 }
 
+#[test]
+fn python_find_managed() {
+    let context: TestContext = TestContext::new_with_versions(&["3.11", "3.12"])
+        .with_filtered_python_sources()
+        .with_versions_as_managed(&["3.12"]);
+
+    // We find the managed interpreter
+    uv_snapshot!(context.filters(), context.python_find().arg("--managed-python"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    [PYTHON-3.12]
+
+    ----- stderr -----
+    ");
+
+    // Request an interpreter that cannot be satisfied
+    uv_snapshot!(context.filters(), context.python_find().arg("--managed-python").arg("3.11"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: No interpreter found for Python 3.11 in virtual environments or managed installations
+    ");
+
+    let context: TestContext = TestContext::new_with_versions(&["3.11", "3.12"])
+        .with_filtered_python_sources()
+        .with_versions_as_managed(&["3.11"]);
+
+    // We find the unmanaged interpreter with managed Python disabled
+    uv_snapshot!(context.filters(), context.python_find().arg("--no-managed-python"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    [PYTHON-3.12]
+
+    ----- stderr -----
+    ");
+
+    // Request an interpreter that cannot be satisfied
+    uv_snapshot!(context.filters(), context.python_find().arg("--no-managed-python").arg("3.11"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: No interpreter found for Python 3.11 in [PYTHON SOURCES]
+    ");
+
+    // We find the unmanaged interpreter with system Python preferred
+    uv_snapshot!(context.filters(), context.python_find().arg("--python-preference").arg("system"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    [PYTHON-3.12]
+
+    ----- stderr -----
+    ");
+
+    // But, if no system Python meets the request, we'll use the managed interpreter
+    uv_snapshot!(context.filters(), context.python_find().arg("--python-preference").arg("system").arg("3.11"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    [PYTHON-3.11]
+
+    ----- stderr -----
+    ");
+}
+
 /// See: <https://github.com/astral-sh/uv/issues/11825>
 ///
 /// This test will not succeed on macOS if using a Homebrew provided interpreter. The interpreter
@@ -786,16 +857,7 @@ fn python_find_script() {
         .with_filtered_python_names()
         .with_filtered_exe_suffix();
 
-    let filters = context
-        .filters()
-        .into_iter()
-        .chain(vec![(
-            r"environments-v2/[\w-]+",
-            "environments-v2/[HASHEDNAME]",
-        )])
-        .collect::<Vec<_>>();
-
-    uv_snapshot!(filters, context.init().arg("--script").arg("foo.py"), @r###"
+    uv_snapshot!(context.filters(), context.init().arg("--script").arg("foo.py"), @r###"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -804,22 +866,22 @@ fn python_find_script() {
     Initialized script at `foo.py`
     "###);
 
-    uv_snapshot!(filters, context.sync().arg("--script").arg("foo.py"), @r"
+    uv_snapshot!(context.filters(), context.sync().arg("--script").arg("foo.py"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
 
     ----- stderr -----
-    Creating script environment at: [CACHE_DIR]/environments-v2/[HASHEDNAME]
+    Creating script environment at: [CACHE_DIR]/environments-v2/foo-[HASH]
     Resolved in [TIME]
     Audited in [TIME]
     ");
 
-    uv_snapshot!(filters, context.python_find().arg("--script").arg("foo.py"), @r"
+    uv_snapshot!(context.filters(), context.python_find().arg("--script").arg("foo.py"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
-    [CACHE_DIR]/environments-v2/[HASHEDNAME]/[BIN]/[PYTHON]
+    [CACHE_DIR]/environments-v2/foo-[HASH]/[BIN]/[PYTHON]
 
     ----- stderr -----
     ");
@@ -885,15 +947,6 @@ fn python_find_script_no_such_version() {
         .with_filtered_python_names()
         .with_filtered_exe_suffix()
         .with_filtered_python_sources();
-    let filters = context
-        .filters()
-        .into_iter()
-        .chain(vec![(
-            r"environments-v2/[\w-]+",
-            "environments-v2/[HASHEDNAME]",
-        )])
-        .collect::<Vec<_>>();
-
     let script = context.temp_dir.child("foo.py");
     script
         .write_str(indoc! {r#"
@@ -904,13 +957,13 @@ fn python_find_script_no_such_version() {
         "#})
         .unwrap();
 
-    uv_snapshot!(filters, context.sync().arg("--script").arg("foo.py"), @r"
+    uv_snapshot!(context.filters(), context.sync().arg("--script").arg("foo.py"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
 
     ----- stderr -----
-    Creating script environment at: [CACHE_DIR]/environments-v2/[HASHEDNAME]
+    Creating script environment at: [CACHE_DIR]/environments-v2/foo-[HASH]
     Resolved in [TIME]
     Audited in [TIME]
     ");
@@ -924,7 +977,7 @@ fn python_find_script_no_such_version() {
         "#})
         .unwrap();
 
-    uv_snapshot!(filters, context.python_find().arg("--script").arg("foo.py"), @r"
+    uv_snapshot!(context.filters(), context.python_find().arg("--script").arg("foo.py"), @r"
     success: false
     exit_code: 1
     ----- stdout -----
